diff src/globals.h @ 20800:e76b83c07bd8 v8.2.0952

patch 8.2.0952: no simple way to interrupt Vim Commit: https://github.com/vim/vim/commit/be5ee8686a50acf07b823bd293f9c765e533d213 Author: Bram Moolenaar <Bram@vim.org> Date: Wed Jun 10 20:56:58 2020 +0200 patch 8.2.0952: no simple way to interrupt Vim Problem: No simple way to interrupt Vim. Solution: Add the SigUSR1 autocommand, triggered by SIGUSR1. (Jacob Hayes, closes #1718)
author Bram Moolenaar <Bram@vim.org>
date Wed, 10 Jun 2020 21:00:04 +0200
parents 90b96fa35e4b
children 2616c5a337e0
line wrap: on
line diff
--- a/src/globals.h
+++ b/src/globals.h
@@ -1171,9 +1171,14 @@ EXTERN int	curscript INIT(= 0);	    // i
 EXTERN FILE	*scriptout  INIT(= NULL);   // stream to write script to
 EXTERN int	read_cmd_fd INIT(= 0);	    // fd to read commands from
 
-// volatile because it is used in signal handler catch_sigint().
-EXTERN volatile sig_atomic_t got_int INIT(= FALSE); // set to TRUE when interrupt
-						// signal occurred
+// Set to TRUE when an interrupt signal occurred.
+// Volatile because it is used in signal handler catch_sigint().
+EXTERN volatile sig_atomic_t got_int INIT(= FALSE);
+
+// Set to TRUE when SIGUSR1 signal was detected.
+// Volatile because it is used in signal handler catch_sigint().
+EXTERN volatile sig_atomic_t got_sigusr1 INIT(= FALSE);
+
 #ifdef USE_TERM_CONSOLE
 EXTERN int	term_console INIT(= FALSE); // set to TRUE when console used
 #endif